﻿using System.Diagnostics;
using System.Globalization;
using System.Windows;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.Styles;
using ThinkGeo.MapSuite.Wpf;

namespace _9409
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        Proj4Projection proj4Projection;

        public MainWindow()
        {
            InitializeComponent();
        }

        private void map_Loaded(object sender, RoutedEventArgs e)
        {
            map.MapUnit = GeographyUnit.Meter;
            LayerOverlay myOverlay = new LayerOverlay();
            map.Overlays.Add(myOverlay);
            myOverlay.Open();

            InMemoryFeatureLayer layer = new InMemoryFeatureLayer();
            layer.InternalFeatures.Add(new Feature(10000000, 10000000));
            layer.InternalFeatures.Add(new Feature(-10000000, -10000000));

            layer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.Capital1;
            layer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            myOverlay.Layers.Add(layer);

            //Apply the projection 
            proj4Projection = new Proj4Projection();
            proj4Projection.InternalProjectionParametersString = "+proj=omerc +lat_0=4 +lonc=102.25 +alpha=323.0257905 +k=0.99984 +x_0=804670.24 +y_0=0 +no_uoff +gamma=323.1301023611111 +a=6377295.664 +b=6356094.667915204 +units=m +no_defs"; //Current Proj in meter
            proj4Projection.ExternalProjectionParametersString = Proj4Projection.GetEpsgParametersString(4326); //Change to the proj with decimal degree
            proj4Projection.Open();

            map.CurrentExtent = myOverlay.GetBoundingBox();
            map.TrackOverlay.TrackMode = TrackMode.Line;
            map.Refresh();
        }

        private void map_MouseMove(object sender, System.Windows.Input.MouseEventArgs e)
        {
            var point = e.MouseDevice.GetPosition(map);

            ScreenPointF screenPointF = new ScreenPointF((float)point.X, (float)point.Y);
            PointShape pointShape = ExtentHelper.ToWorldCoordinate(map.CurrentExtent, screenPointF, (float)map.ActualWidth, (float)map.ActualHeight);


            string x = pointShape.X.ToString("f6", CultureInfo.InvariantCulture);
            string y = pointShape.Y.ToString("f6", CultureInfo.InvariantCulture);

            if (proj4Projection != null)
            {
                PointShape p2 = proj4Projection.ConvertToExternalProjection(pointShape) as PointShape;

                string tmpstring = "RSO_WEST(KERTAU)" + "(" + (y) + "," + " " + (x) + ")" + " " + " Lat: " + DecimalDegreesHelper.GetDegreesMinutesSecondsStringFromDecimalDegree(p2.Y) + "Long: " + DecimalDegreesHelper.GetDegreesMinutesSecondsStringFromDecimalDegree(p2.X) + " " + "Height :" + "m";

                TextBoxSatu.Text = tmpstring;
                Debug.WriteLine(tmpstring);
            }
        }
    }
}
